## OpenGen

Code generation tool for OpEn

### Installation 
To use this Python package, run:

```
pip install opengen
```

You will then be able to use it in your project with

```python
from opengen import *
```

or 

```python
import opengen as og
```

In order to build the auto-generated code, you need the 
Rust compiler. This is still work in progress. Further
documentation will be provided soon.

